@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-08-01'; # DATE
-our $VERSION = '0.19'; # VERSION
+our $DATE = '2015-09-10'; # DATE
+our $VERSION = '0.20'; # VERSION
 
 use 5.010001;
 use strict;
@@ -208,6 +208,10 @@ _
             schema => 'str*',
             tags => ['category:extra-code'],
         },
+        code_after_end => {
+            schema => 'str*',
+            tags => ['category:extra-code'],
+        },
 
         output_file => {
             summary => 'Set output file, defaults to stdout',
@@ -730,7 +734,7 @@ _
             "",
             $shebang_line, "\n",
 
-            ($args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
+            ("# code_after_shebang\n", $args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
 
             "# PERICMD_INLINE_SCRIPT: ", do {
                 require JSON;
@@ -780,11 +784,13 @@ _
                 sort keys %{$cd->{subs}}),
             "\n",
 
-            ($args{code_before_parse_cmdline_options}, "\n") x !!$args{code_before_parse_cmdline_options},
+            ("# code_before_parse_cmdline_options\n", $args{code_before_parse_cmdline_options}, "\n") x !!$args{code_before_parse_cmdline_options},
 
             @l,
 
             $dp_code2,
+
+            ("# code_after_end\n", $args{code_after_end}, "\n") x !!$args{code_after_end},
         );
     }
 
@@ -836,7 +842,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.19 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-08-01.
+This document describes version 0.20 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-09-10.
 
 =head1 SYNOPSIS
 
@@ -862,32 +868,31 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                    Rate  run 1 (lite) run --version (lite)     -c (lite) run 1 (inline) run --version (inline)  -c (inline)   perl
- run 1 (lite)           9.7993+-0.0045/s            --               -57.2%        -76.7%         -84.0%                 -87.8%       -88.7% -94.4%
- run --version (lite)     22.87+-0.028/s  133.39+-0.3%                   --        -45.7%         -62.8%                 -71.6%       -73.5% -86.9%
- -c (lite)               42.116+-0.067/s 329.78+-0.71%         84.15+-0.37%            --         -31.4%                 -47.7%       -51.2% -75.9%
- run 1 (inline)              61.4+-2.1/s      527+-22%          168.5+-9.4%    45.8+-5.1%             --                 -23.8%       -28.9% -64.9%
- run --version (inline)      80.6+-3.2/s      723+-33%             252+-14%    91.4+-7.6%       31.3+-7%                     --        -6.7% -53.9%
- -c (inline)              86.35+-0.049/s        781.2%         277.56+-0.5% 105.03+-0.35%     40.6+-4.9%              7.1+-4.3%           -- -50.6%
- perl                     174.75+-0.68/s    1683.3+-7%          664.1+-3.1%   314.9+-1.8%     184.6+-10%            116.8+-8.7% 102.38+-0.8%     --
+                                   Rate  run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
+ run 1 (lite)           12.854+-0.019/s            --               -61.1%      -82.1%         -89.0%                 -91.7%      -93.7% -97.6%
+ run --version (lite)         33+-0.1/s 156.75+-0.87%                   --      -54.0%         -71.7%                 -78.6%      -83.9% -93.9%
+ -c (lite)                 71.73+-0.3/s     458+-2.4%          117.3+-1.1%          --         -38.6%                 -53.5%      -65.1% -86.8%
+ run 1 (inline)          116.76+-0.99/s   808.3+-7.8%          253.8+-3.2%  62.8+-1.5%             --                 -24.2%      -43.2% -78.4%
+ run --version (inline)  154.09+-0.58/s  1098.8+-4.9%          366.9+-2.3% 114.8+-1.2%       32+-1.2%                     --      -25.0% -71.5%
+ -c (inline)               205.5+-1.4/s     1498+-11%          522.5+-4.6% 186.4+-2.3%       76+-1.9%               33.3+-1%          -- -62.1%
+ perl                        541.5+-4/s     4113+-32%            1541+-13%   655+-6.4%    363.8+-5.2%            251.5+-2.9% 163.6+-2.7%     --
  
  Average times:
-   perl                  :     5.7225ms
-   -c (inline)           :    11.5808ms
-   run --version (inline):    12.4069ms
-   run 1 (inline)        :    16.2866ms
-   -c (lite)             :    23.7439ms
-   run --version (lite)  :    43.7254ms
-   run 1 (lite)          :   102.0481ms
+   perl                  :     1.8467ms
+   -c (inline)           :     4.8662ms
+   run --version (inline):     6.4897ms
+   run 1 (inline)        :     8.5646ms
+   -c (lite)             :    13.9412ms
+   run --version (lite)  :    30.3030ms
+   run 1 (lite)          :    77.7968ms
 
 =head1 FUNCTIONS
 
 
 =head2 gen_inline_pericmd_script(%args) -> [status, msg, result, meta]
 
-{en_US Generate inline Perinci::CmdLine CLI script}.
+Generate inline Perinci::CmdLine CLI script.
 
-{en_US 
 The goal of this module is to let you create a CLI script from a Riap
 function/metadata. This is like what C<Perinci::CmdLine::Lite> or
 C<Perinci::CmdLine::Classic> does, except that the generated CLI script will have
@@ -936,7 +941,6 @@ TODO:
 =item * Option to validate argument (using periswrap).
 
 =item * Support per_arg_json.
-}
 
 =back
 
@@ -946,7 +950,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<actions> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
+
+=item * B<code_after_end> => I<str>
 
 =item * B<code_after_shebang> => I<str>
 
@@ -954,137 +960,135 @@ Arguments ('*' denotes required arguments):
 
 =item * B<common_opts> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<completion> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<config_dirs> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<config_filename> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<default_subcommand> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<description> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<env_name> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<exit> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<extra_urls_for_version> => I<array[str]>
 
-{en_US More URLs to show version for --version}.
+More URLs to show version for --version.
 
-{en_US 
 Currently not implemented in Perinci::CmdLine::Inline.
-}
 
 =item * B<formats> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<get_subcommand_from_arg> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<include> => I<array[str]>
 
-{en_US Include extra modules}.
+Include extra modules.
 
 =item * B<log> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<meta> => I<hash>
 
-{en_US An alternative to specifying `url`}.
+An alternative to specifying `url`.
 
 =item * B<meta_is_normalized> => I<bool>
 
 =item * B<output_file> => I<str>
 
-{en_US Set output file, defaults to stdout}.
+Set output file, defaults to stdout.
 
 =item * B<overwrite> => I<bool>
 
 =item * B<pass_cmdline_object> => I<bool> (default: 0)
 
-{en_US Whether to pass Perinci::CmdLine::Inline object}.
+Whether to pass Perinci::CmdLine::Inline object.
 
 =item * B<program_name> => I<str>
 
-{en_US Program name}.
+Program name.
 
 =item * B<program_version> => I<str>
 
-{en_US Program version (otherwise will use version from url metadata)}.
+Program version (otherwise will use version from url metadata).
 
 =item * B<read_config> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<read_env> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<riap_client> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<riap_client_args> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<riap_version> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<shebang> => I<str>
 
-{en_US Set shebang line}.
+Set shebang line.
 
 =item * B<skip_format> => I<bool> (default: 0)
 
-{en_US Assume that function returns raw text that need no formatting, do not offer --format, --json, --naked-res}.
+Assume that function returns raw text that need no formatting, do not offer --format, --json, --naked-res.
 
 =item * B<sub_name> => I<str>
 
 =item * B<subcommands> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<summary> => I<str>
 
-{en_US Program summary}.
+Program summary.
 
 =item * B<tags> => I<any>
 
-{en_US Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base}.
+Currently does nothing, provided only for compatibility with Perinci::CmdLine::Base.
 
 =item * B<url> => I<str>
 
-{en_US Program URL}.
+Program URL.
 
 =item * B<validate_args> => I<bool> (default: 1)
 
-{en_US Whether to validate arguments using schemas}.
+Whether to validate arguments using schemas.
 
 =item * B<with_debug> => I<bool>
 
-{en_US Generate script with debugging outputs}.
+Generate script with debugging outputs.
 
 =back
 
